pub struct CrawlScrapeOptions {
pub formats: Option<Vec<CrawlScrapeFormats>>,
pub only_main_content: Option<bool>,
pub include_tags: Option<Vec<String>>,
pub exclude_tags: Option<Vec<String>>,
pub headers: Option<HashMap<String, String>>,
pub wait_for: Option<u32>,
pub timeout: Option<u32>,
}Fields
formats: Option<Vec<CrawlScrapeFormats>>Formats to extract from the page. (default: [ Markdown ])
only_main_content: Option<bool>Only extract the main content of the page, excluding navigation and other miscellaneous content. (default: true)
HTML tags to exclusively include.
For example, if you pass div, you will only get content from <div>s and their children.
HTML tags to exclude.
For example, if you pass img, you will never get image URLs in your results.
headers: Option<HashMap<String, String>>Additional HTTP headers to use when loading the page.
wait_for: Option<u32>Amount of time to wait after loading the page, and before grabbing the content, in milliseconds. (default: 0)
timeout: Option<u32>Timeout before returning an error, in milliseconds. (default: 60000)