pub struct CrawlStatus {
pub status: CrawlStatusTypes,
pub total: u32,
pub completed: u32,
pub credits_used: u32,
pub expires_at: String,
pub next: Option<String>,
pub data: Vec<Document>,
}Fields
status: CrawlStatusTypesThe status of the crawl.
total: u32Number of pages that will be scraped in total. This number may grow as the crawler discovers new pages.
completed: u32Number of pages that have been successfully scraped.
credits_used: u32Amount of credits used by the crawl job.
expires_at: StringExpiry time of crawl data. After this date, the crawl data will be unavailable from the API.
next: Option<String>URL to call to get the next batch of documents. Unless you are sidestepping the SDK, you do not need to deal with this.
data: Vec<Document>List of documents returned by the crawl