pub struct CrawlUrlInput {
pub url: String,
pub options: CrawlOptions,
pub poll_interval: Option<u64>,
pub idempotency_key: Option<String>,
pub webhook: Option<Webhook>,
}Fields
url: StringStarting URL for the crawl
options: CrawlOptionspoll_interval: Option<u64>How often the status of the job should be checked, in milliseconds. (default: 2000)
idempotency_key: Option<String>webhook: Option<Webhook>Webhook URL to notify when crawl is complete, default to a dummy url