pub struct Document {
pub markdown: Option<String>,
pub html: Option<String>,
pub raw_html: Option<String>,
pub screenshot: Option<String>,
pub links: Option<Vec<String>>,
pub extract: Option<Value>,
pub json: Option<Value>,
pub actions: Option<ActionResults>,
pub metadata: DocumentMetadata,
pub warning: Option<String>,
}Fields
markdown: Option<String>A list of the links on the page, present if ScrapeFormats::Markdown is present in ScrapeOptions.formats. (default)
html: Option<String>The HTML of the page, present if ScrapeFormats::HTML is present in ScrapeOptions.formats.
This contains HTML that has non-content tags removed. If you need the original HTML, use ScrapeFormats::RawHTML.
raw_html: Option<String>The raw HTML of the page, present if ScrapeFormats::RawHTML is present in ScrapeOptions.formats.
This contains the original, untouched HTML on the page. If you only need human-readable content, use ScrapeFormats::HTML.
screenshot: Option<String>The URL to the screenshot of the page, present if ScrapeFormats::Screenshot or ScrapeFormats::ScreenshotFullPage is present in ScrapeOptions.formats.
links: Option<Vec<String>>A list of the links on the page, present if ScrapeFormats::Links is present in ScrapeOptions.formats.
extract: Option<Value>The extracted data from the page, present if ScrapeFormats::Extract is present in ScrapeOptions.formats.
If ScrapeOptions.extract.schema is Some, this Value is guaranteed to match the provided schema.
json: Option<Value>The structured JSON data from the page, present if ScrapeFormats::JSON is present in ScrapeOptions.formats.
If ScrapeOptions.jsonOptions.schema is Some, this Value is guaranteed to match the provided schema.
actions: Option<ActionResults>Results of actions performed during scraping, present if actions parameter was provided in the request.
metadata: DocumentMetadataThe metadata from the page.
warning: Option<String>Can be present if ScrapeFormats::Extract is present in ScrapeOptions.formats.
The warning message will contain any errors encountered during the extraction.